@@ -51,6 +51,13 @@ char * box_filename;
 GtkWidget *scorelabel;
 scoretable sctab[] = {{5, 10}, {6, 12}, {7, 18}, {8, 28}, {9, 42}, {10, 82}, {11, 108}, {12, 138}, {13, 172}, {14, 210}, {0,0}};
 
+/* predeclare the menus */
+
+GnomeUIInfo gamemenu[];
+GnomeUIInfo settingsmenu[];
+GnomeUIInfo helpmenu[];
+GnomeUIInfo mainmenu[];
+
 static void 
 load_image (gchar *fname,
 GdkPixmap **pixmap,
@@ -63,7 +70,7 @@ GdkPixmap **mask)
     
 	tmp = g_strconcat ( "glines/", fname, NULL);
 
-	fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, (tmp), FALSE, NULL);
+	fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, (tmp), FALSE, NULL);
 	g_free( tmp );
 
 	if (!g_file_test (fn, G_FILE_TEST_EXISTS)) {
@@ -146,7 +153,7 @@ start_game(void)
 	active = -1;
 	target = -1;
 	inmove = -1;
-	snprintf(string, 19, "%d", score);
+	g_snprintf(string, 19, "%d", score);
 	gtk_label_set_text(GTK_LABEL(scorelabel), string);
 	set_inmove(0);
 }
@@ -183,6 +190,24 @@ draw_preview(void)
 	}
 }
 
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+
+	top = gnome_score_get_notable("glines", NULL, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (gamemenu[2].widget, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (gamemenu[2].widget, FALSE);
+	}
+}
+
 void
 game_over(void)
 {
@@ -191,6 +216,7 @@ game_over(void)
 	gnome_appbar_set_status(GNOME_APPBAR(appbar), _("Game Over!"));
 	pos = gnome_score_log(score, NULL, TRUE);
 	gnome_scores_display(_("Glines"), "glines", NULL, pos); 
+	update_score_state ();
 	return;
 }
 
@@ -611,7 +637,7 @@ check_goal(GtkWidget *widget, int num, int is_score)
 		{
 			char string[20];
 			score += addscore(count+1);
-			snprintf(string, 19, "%d", score);
+			g_snprintf(string, 19, "%d", score);
 			gtk_label_set_text(GTK_LABEL(scorelabel), string);
 		}
 
@@ -732,7 +758,7 @@ game_about_callback (GtkWidget *widget, void *data)
 	   char *filename = NULL;
 
 	   filename = gnome_program_locate_file (NULL,
-			   GNOME_FILE_DOMAIN_PIXMAP,  ("glines.png"),
+			   GNOME_FILE_DOMAIN_APP_PIXMAP,  ("glines.png"),
 			   TRUE, NULL);
 	   if (filename != NULL)
 	   {
@@ -814,7 +840,7 @@ static void
 fill_menu (GtkWidget *menu, char * mtype, gboolean bg)
 {
 	struct dirent *e;
-	char *dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, ("glines"), FALSE, NULL);
+	char *dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, ("glines"), FALSE, NULL);
 	DIR *dir;
         int itemno = 0;
 	
@@ -1168,7 +1194,7 @@ main (int argc, char *argv [])
 			      argc, argv,
 			      GNOME_PARAM_POPT_TABLE, NULL,
 			      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/glines.xpm");
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/glines.png");
 	client = gnome_master_client ();
 
 	g_signal_connect (G_OBJECT (client), "save_yourself",
@@ -1249,6 +1275,8 @@ main (int argc, char *argv [])
 
 	gtk_widget_realize(next_draw_area);
 
+	update_score_state ();
+
 	gtk_widget_show(draw_area);
 	gtk_widget_show(next_draw_area);
 
