@@ -17,6 +17,10 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "worm.h"
 #include "gnibbles.h"
 #include "boni.h"
@@ -35,7 +39,7 @@ extern gint current_level;
 
 GnibblesWorm *gnibbles_worm_new (guint t_number)
 {
-        GnibblesWorm *tmp = (GnibblesWorm *) malloc (sizeof (GnibblesWorm));
+        GnibblesWorm *tmp = (GnibblesWorm *) g_malloc (sizeof (GnibblesWorm));
 
 	tmp->xoff = (gint8 *) malloc (CAPACITY * sizeof (gint8));
 	tmp->yoff = (gint8 *) malloc (CAPACITY * sizeof (gint8));
@@ -369,7 +373,7 @@ void gnibbles_worm_undraw_nth (GnibblesWorm *worm, gint offset)
 	y = worm->yhead;
 
 	i = worm->start - 1;
-	if (i == 0)
+	if (i <= 0)
 		i = CAPACITY - 1;
 
 	for (j = 0; j < offset; j++) {
@@ -394,7 +398,7 @@ void gnibbles_worm_undraw_nth (GnibblesWorm *worm, gint offset)
 					 i == worm->stop - 1))
 				return;
 			i--;
-			if (i == 0)
+			if (i == 0 && worm->stop == 0)
 				i = CAPACITY - 1;
 		}
 	}
