@@ -51,7 +51,6 @@ GnomeUIInfo prefmenu[] = {
 /**********************************************************************/
 GnomeUIInfo helpmenu[] = {
   GNOMEUIINFO_HELP(GAME_NAME),
-  GNOMEUIINFO_SEPARATOR,
   GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb, NULL),
   GNOMEUIINFO_END
 };
@@ -76,28 +75,6 @@ GnomeUIInfo mainmenu[] = {
 /* Function Definitions                                               */
 /**********************************************************************/
 
-/**
- * really_new_cb
- * @widget: Pointer to widget
- * @data: Callback data
- *
- * Description:
- * Callback to really start new game
- *
- * Returns:
- **/
-static void really_new_cb(
-GtkWidget *widget,
-gpointer  data
-){
-  gint button = GPOINTER_TO_INT(data);
-    
-  if(button != 0) return;
-
-  start_new_game();
-}
-
-
 /**
  * new_cb
  * @widget: Pointer to widget
@@ -112,22 +89,23 @@ static void new_cb(
 GtkWidget *widget,
 gpointer  data
 ){
-  GtkWidget *box;
 
   if(game_state != STATE_NOT_PLAYING){
-    box = gnome_message_box_new(_("Do you really want to start a new game?"),
-				GNOME_MESSAGE_BOX_QUESTION,
-				GNOME_STOCK_BUTTON_YES,
-				GNOME_STOCK_BUTTON_NO,
-				NULL);
-    gnome_dialog_set_parent (GNOME_DIALOG(box), GTK_WINDOW(app));
-    gnome_dialog_set_default (GNOME_DIALOG(box), 0);
-    gtk_window_set_modal (GTK_WINDOW(box), TRUE);
-    gtk_signal_connect (GTK_OBJECT(box), "clicked",
-			GTK_SIGNAL_FUNC(really_new_cb), NULL);
-    gtk_widget_show(box);
+    GtkWidget *mb;
+    int response;
+    mb = gtk_message_dialog_new (GTK_WINDOW(app), 
+				 GTK_DIALOG_MODAL,
+				 GTK_MESSAGE_WARNING,
+				 GTK_BUTTONS_YES_NO,
+				 _("Do you really want to restart the current game?"),
+				 NULL);
+    response = gtk_dialog_run (GTK_DIALOG(mb));
+    gtk_widget_destroy (mb);
+    if (response == GTK_RESPONSE_YES) {
+      start_new_game();
+    }
   } else {
-    really_new_cb(widget, (gpointer)0);
+    start_new_game();
   }
 }
 
@@ -168,28 +146,6 @@ gpointer  data
 }
 
 
-/**
- * really_exit_cb
- * @widget: Pointer to widget
- * @data: Callback data
- *
- * Description:
- * Callback to really exit game
- *
- * Returns:
- **/
-void really_exit_cb(
-GtkWidget *widget,
-gpointer  data
-){
-  gint button = GPOINTER_TO_INT(data);
-    
-  if(button != 0) return;
-
-  gtk_main_quit();
-}
-
-
 /**
  * exit_cb
  * @widget: Pointer to widget
@@ -200,26 +156,28 @@ gpointer  data
  *
  * Returns:
  **/
-void exit_cb(
-GtkWidget *widget,
-gpointer  data
-){
-  GtkWidget *box;
-
-  if(game_state != STATE_NOT_PLAYING){
-    box = gnome_message_box_new(_("Do you really want to quit the game?"),
-				GNOME_MESSAGE_BOX_QUESTION,
-				GNOME_STOCK_BUTTON_YES,
-				GNOME_STOCK_BUTTON_NO,
-				NULL);
-    gnome_dialog_set_parent(GNOME_DIALOG(box), GTK_WINDOW(app));
-    gnome_dialog_set_default(GNOME_DIALOG(box), 0);
-    gtk_window_set_modal(GTK_WINDOW(box), TRUE);
-    gtk_signal_connect(GTK_OBJECT(box), "clicked",
-		       GTK_SIGNAL_FUNC(really_exit_cb), NULL);
-    gtk_widget_show(box);
+void
+exit_cb(GtkWidget *widget, gpointer  data)
+{
+  if(game_state != STATE_NOT_PLAYING) {
+    GtkWidget *mb;
+    int response;
+    mb = gtk_message_dialog_new (GTK_WINDOW(app), 
+				 GTK_DIALOG_MODAL,
+				 GTK_MESSAGE_QUESTION,
+				 GTK_BUTTONS_NONE,
+				 _("Do you really want to quit the game?"),
+				 NULL);
+    gtk_dialog_add_buttons (GTK_DIALOG(mb), GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+			    GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT,
+			    NULL);
+    response = gtk_dialog_run (GTK_DIALOG(mb));
+    gtk_widget_destroy (mb);
+    if (response == GTK_RESPONSE_ACCEPT) {
+      gtk_main_quit();
+    }
   } else {
-    really_exit_cb(widget, (gpointer)0);
+    gtk_main_quit();
   }
 }
 
@@ -239,6 +197,7 @@ GtkWidget *widget,
 gpointer data
 ){
   GtkWidget *about = NULL;
+  GdkPixbuf *pixbuf = NULL;
   
   const gchar *authors[]= {
     "Mark Rae <m.rae@inpharmatica.co.uk>",
@@ -248,18 +207,30 @@ gpointer data
                 	  NULL
         		  };
   /* Translator credits */
-  gchar *translator_credits = _("");
+  gchar *translator_credits = _("translator_credits");
+
+  {
+	  char *filename = NULL;
+
+	  filename = gnome_program_locate_file (NULL,
+			  GNOME_FILE_DOMAIN_APP_PIXMAP,  ("gnome-gnobots2.png"),
+			  TRUE, NULL);
+	  if (filename != NULL)
+	  {
+		  pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+		  g_free (filename);
+	  }
+  }
   
   about = gnome_about_new(_("Gnobots II"), VERSION,
                           "(C) 1998 Mark Rae",
                           _("Gnome Robots Game"),
                           (const char **)authors,
                           (const char **)documenters,
-                          (const char *)translator_credits,
-                          NULL);
-  gnome_dialog_set_parent(GNOME_DIALOG(about), GTK_WINDOW(app));
-  gtk_window_set_modal(GTK_WINDOW(about), TRUE);
-
+                          strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+                          pixbuf);
+  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW(app));
+  
   gtk_widget_show(about);
 }
 
@@ -283,3 +254,36 @@ gboolean create_game_menus(
 }
 
 /**********************************************************************/
+
+/**
+ * update_score_state
+ *
+ * Description:
+ * Changes menu item enabled/disabled state depending on high score availability
+ **/
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+	gchar sbuf[256];
+
+	  if(properties_super_safe_moves()){
+	    sprintf(sbuf, "%s-super-safe", game_config_filename(current_game_config()));
+	  } else if(properties_safe_moves()){
+	    sprintf(sbuf, "%s-safe", game_config_filename(current_game_config()));
+	  } else {
+	    sprintf(sbuf, "%s", game_config_filename(current_game_config()));
+	  }
+
+	top = gnome_score_get_notable(GAME_NAME, sbuf, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (gamemenu[2].widget, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (gamemenu[2].widget, FALSE);
+	}
+}
