@@ -10,7 +10,13 @@
 extern "C" {
 #endif /* __cplusplus */
 
+enum {
+	MINE_NOMARK = 0,
+	MINE_MARKED,
+	MINE_QUESTION
+};
 
+#define TYPE_GTK_MINEFIELD (gtk_minefield_get_type ())
 #define GTK_MINEFIELD(obj) GTK_CHECK_CAST(obj, gtk_minefield_get_type(), GtkMineField)
 #define GTK_MINEFIELD_CLASS(klass) GTK_CHECK_CLASS_CAST(klass, gtk_minefield_get_type(), GtkMineFieldClass);
 #define GTK_IS_MINEFIELD(obj) GTK_CHECK_TYPE(obj, gtk_minefield_get_type())
@@ -21,9 +27,9 @@ typedef struct _GtkMineFieldClass    GtkMineFieldClass;
 struct _Mine {
 	guint mined:1;
 	guint shown:1;
-	guint marked:1;
+	guint marked:2;
 	guint down:1;
-        guint neighbours;
+	guint neighbours;
 };
 
 typedef struct _Mine mine;
@@ -40,11 +46,11 @@ struct _Sign
     };
   
 struct _GtkMineField {
-        GtkWidget widget;
-        guint xsize, ysize;
-        guint mcount;
+	GtkWidget widget;
+	guint xsize, ysize;
+	guint mcount;
 	mine *mines;
-	guint flags;
+	guint flag_count;
 	guint shown;
 	gint cdown;
         guint cdownx;
@@ -55,14 +61,16 @@ struct _GtkMineField {
 	gint multi_mode;
         sign flag;
         sign mine;
-        GdkFont   *font;
-	GdkColorContext *cc;
+	sign question;
+
+	gboolean started;
+
 	struct {
-		char text[2];
+		PangoLayout *layout;
 		gint dx, dy;
-		GdkGC *gc;
 	} numstr[9];
 	guint minesize;
+	gint in_play;
 };
 
 struct _GtkMineFieldClass
